/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.admin.junit;

import java.util.List;
import java.util.regex.Pattern;
import java.util.regex.PatternSyntaxException;

import org.ow2.petals.admin.api.EndpointDirectoryAdministration;
import org.ow2.petals.admin.api.exception.EndpointDirectoryAdministrationException;
import org.ow2.petals.admin.api.exception.EndpointDirectoryRegexpPatternException;
import org.ow2.petals.admin.endpoint.Endpoint;
import org.ow2.petals.admin.endpoint.EndpointDirectoryView;

/**
 * 
 * @author "Mathieu CARROLLE - EBM WebSourcing"
 *
 */
public class EndpointDirectoryAdministrationMock implements EndpointDirectoryAdministration {

    private static final String DEFAULT_REGEXP = ".*";

    private final EndpointDirectoryViewMock endpointDirectoryView = new EndpointDirectoryViewMock();

    @Override
    public EndpointDirectoryView getEndpointDirectoryContent(final String containerNameRegex,
            final String endpointNameRegex, final String serviceNameRegex, final String interfaceNameRegex)
            throws EndpointDirectoryRegexpPatternException, EndpointDirectoryAdministrationException {
        try {
            final Pattern containerNamePattern = Pattern
                    .compile(containerNameRegex == null ? DEFAULT_REGEXP : containerNameRegex);
            final Pattern endpointNamePattern = Pattern
                    .compile(endpointNameRegex == null ? DEFAULT_REGEXP : endpointNameRegex);
            final Pattern serviceNamePattern = Pattern
                    .compile(serviceNameRegex == null ? DEFAULT_REGEXP : serviceNameRegex);
            final Pattern interfaceNamePattern = Pattern
                    .compile(interfaceNameRegex == null ? DEFAULT_REGEXP : interfaceNameRegex);

            return filteredEndpoints(containerNamePattern, endpointNamePattern, serviceNamePattern,
                    interfaceNamePattern);

        } catch (final PatternSyntaxException e) {
            throw new EndpointDirectoryRegexpPatternException(e.getPattern(), e.getDescription());
        }
    }

    private EndpointDirectoryView filteredEndpoints(Pattern containerNamePattern, Pattern endpointNamePattern,
            Pattern serviceNamePattern, Pattern interfaceNamePattern) {
        EndpointDirectoryViewMock filteredEndpoints = new EndpointDirectoryViewMock();

        for (Endpoint e : endpointDirectoryView.getAllEndpoints()) {

            boolean matchingEndpoint = containerNamePattern.matcher(e.getContainerName()).matches()
                    && endpointNamePattern.matcher(e.getEndpointName()).matches()
                    && serviceNamePattern.matcher(e.getServiceName()).matches();

            if (matchingEndpoint) {
                for (String interfaceName : e.getInterfaceNames()) {
                    if (interfaceNamePattern.matcher(interfaceName).matches()) {
                    filteredEndpoints.getAllEndpoints().add(e);
                        break;
                    }
                }
            }
        }
        return filteredEndpoints;
    }

    public void setEndpoints(List<Endpoint> endpoints) {
        endpointDirectoryView.getAllEndpoints().clear();
        endpointDirectoryView.getAllEndpoints().addAll(endpoints);
    }

}
